@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package WWW::Spotify;
-$WWW::Spotify::VERSION = '0.008';
+$WWW::Spotify::VERSION = '0.009';
 use Moo 2.002004;
 
 use Data::Dumper;
@@ -18,7 +18,6 @@ use Types::Standard qw( Bool InstanceOf Int Str );
 use URI;
 use URI::Escape;
 use WWW::Mechanize;
-use XML::Simple;
 
 has 'oauth_authorize_url' => (
     is      => 'rw',
@@ -448,6 +447,7 @@ sub format_results {
     if ( $self->auto_xml_decode && $self->result_format eq 'xml' ) {
 
         # FIX ME
+        require XML::Simple;
         my $xs = XML::Simple->new();
         return $xs->XMLin($content);
     }
@@ -970,7 +970,7 @@ WWW::Spotify - Spotify Web API Wrapper
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -1238,7 +1238,7 @@ Aaron Johnson <aaronjjohnson@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Aaron Johnson.
+This software is copyright (c) 2014-2017 by Aaron Johnson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
